@@ -1,12 +1,7 @@
-from __future__ import absolute_import, division, print_function
-
 import time
 
-from openai import api_requestor, util
+from openai import util
 from openai.api_resources.abstract import (
-    APIResource,
-    CreateableAPIResource,
-    DeletableAPIResource,
     ListableAPIResource,
     UpdateableAPIResource,
 )
@@ -31,7 +26,10 @@ class Engine(ListableAPIResource, UpdateableAPIResource):
                 if timeout is not None and time.time() > start + timeout:
                     raise
 
-                util.log_info("Waiting for snapshot to warm up", error=e)
+                util.log_info("Waiting for model to warm up", error=e)
 
     def search(self, **params):
         return self.request("post", self.instance_url() + "/search", params)
+
+    def embeddings(self, **params):
+        return self.request("post", self.instance_url() + "/embeddings", params)
