@@ -3,15 +3,15 @@ import os
 import signal
 import sys
 import warnings
-from openai.validators import (
-    write_out_file,
-    apply_necessary_remediation,
-    apply_optional_remediation,
-    read_any_format,
-    get_validators,
-)
 
 import openai
+from openai.validators import (
+    apply_necessary_remediation,
+    apply_optional_remediation,
+    get_validators,
+    read_any_format,
+    write_out_file,
+)
 
 
 class bcolors:
@@ -102,7 +102,6 @@ class Engine:
 
     @classmethod
     def search(cls, args):
-        # Will soon be deprecated and replaced by a Search.create
         params = {
             "query": args.query,
             "max_rerank": args.max_rerank,
@@ -113,6 +112,9 @@ class Engine:
         if args.file:
             params["file"] = args.file
 
+        if args.version:
+            params["version"] = args.version
+
         resp = openai.Engine(id=args.id).search(**params)
         scores = [
             (search_result["score"], search_result["document"])
@@ -201,6 +203,7 @@ class File:
         resp = openai.File.create(
             file=open(args.file),
             purpose=args.purpose,
+            model=args.model,
         )
         print(resp)
 
@@ -220,6 +223,17 @@ class File:
         print(file)
 
 
+class Search:
+    @classmethod
+    def create_alpha(cls, args):
+        resp = openai.Search.create_alpha(
+            query=[args.query],
+            max_documents=args.max_documents,
+            file_id=args.file,
+        )
+        print(resp)
+
+
 class FineTune:
     @classmethod
     def list(cls, args):
@@ -588,6 +602,11 @@ Mutually exclusive with `top_p`.""",
         type=bool,
         default=False,
     )
+    sub.add_argument(
+        "--version",
+        help="The version of the search routing to use",
+    )
+
     sub.add_argument("-q", "--query", required=True, help="Search query")
     sub.set_defaults(func=Engine.search)
 
@@ -669,6 +688,11 @@ Mutually exclusive with `top_p`.""",
         help="Why are you uploading this file? (see https://beta.openai.com/docs/api-reference/ for purposes)",
         required=True,
     )
+    sub.add_argument(
+        "-m",
+        "--model",
+        help="Model for search indexing (e.g. 'ada'). Only meaningful if --purpose is 'search'.",
+    )
     sub.set_defaults(func=File.create)
 
     sub = subparsers.add_parser("files.get")
@@ -682,6 +706,30 @@ Mutually exclusive with `top_p`.""",
     sub = subparsers.add_parser("files.list")
     sub.set_defaults(func=File.list)
 
+    # Search
+    sub = subparsers.add_parser("search.create_alpha")
+
+    sub.add_argument(
+        "-f",
+        "--file",
+        required=True,
+        help="ID for previously uploaded file that contains the documents you want to search",
+    )
+    sub.add_argument(
+        "-m",
+        "--max_documents",
+        help="The maximum number of documents to return",
+        type=int,
+        default=200,
+    )
+    sub.add_argument(
+        "-q",
+        "--query",
+        required=True,
+        help="Search query",
+    )
+    sub.set_defaults(func=Search.create_alpha)
+
     # Finetune
     sub = subparsers.add_parser("fine_tunes.list")
     sub.set_defaults(func=FineTune.list)
